@@ -1,3 +1,5 @@
+from datetime import datetime
+from hashlib import md5
 from re import compile
 
 from .enums import PacketType
@@ -11,6 +13,11 @@ class AcarsMessage:
         self.from_station = from_station
         self.msg_type = msg_type
         self.message = message
+        self.timestamp = datetime.now()
+
+    @property
+    def hash(self) -> str:
+        return md5(f"{self.from_station}{self.message}{self.timestamp.timestamp()}".encode("UTF-8")).hexdigest()
 
     def __str__(self) -> str:
         return f"AcarsMessage(From: {self.from_station}, Type: {self.msg_type}, Message: {self.message})"
